import { type RequestEvent, type Handle } from "@sveltejs/kit";
import type { Client } from "gel";
import { type BuiltinOAuthProviderNames, type TokenData, type emailPasswordProviderName, type AuthenticationResponseJSON, type RegistrationResponseJSON } from "@gel/auth-core";
import { ClientAuth, type AuthOptions } from "./client.js";
export * from "@gel/auth-core/errors";
export type { TokenData, AuthOptions, Client };
export type BuiltinProviderNames = BuiltinOAuthProviderNames | typeof emailPasswordProviderName;
type ParamsOrError<Result extends object, ErrorDetails extends object = object> = ({
    error: null;
} & {
    [Key in keyof ErrorDetails]?: undefined;
} & Result) | ({
    error: Error;
} & ErrorDetails & {
    [Key in keyof Result]?: undefined;
});
export interface AuthRouteHandlers {
    onOAuthCallback?: (params: ParamsOrError<{
        tokenData: TokenData;
        provider: BuiltinOAuthProviderNames;
        isSignUp: boolean;
    }>) => Promise<never>;
    onBuiltinUICallback?: (params: ParamsOrError<({
        tokenData: TokenData;
        provider: BuiltinProviderNames;
    } | {
        tokenData: null;
        provider: null;
    }) & {
        isSignUp: boolean;
    }>) => Promise<never>;
    onEmailVerify?: (params: ParamsOrError<{
        tokenData: TokenData;
    }, {
        verificationToken?: string;
    }>) => Promise<never>;
    onMagicLinkCallback?: (params: ParamsOrError<{
        tokenData: TokenData;
        isSignUp: boolean;
    }>) => Promise<Response>;
    onSignout?: () => Promise<never>;
}
export default function serverAuth(client: Client, options: AuthOptions): {
    createServerRequestAuth: (event: RequestEvent) => ServerRequestAuth;
    createAuthRouteHook: (handlers: AuthRouteHandlers) => Handle;
};
export declare class ServerRequestAuth extends ClientAuth {
    private readonly client;
    private readonly core;
    private readonly cookies;
    private _session;
    private setVerifierCookie;
    private setAuthCookie;
    private deleteVerifierCookie;
    private deleteAuthCookie;
    get session(): AuthSession;
    isPasswordResetTokenValid(resetToken: string): boolean | null;
    getProvidersInfo(): Promise<{
        oauth: {
            name: BuiltinOAuthProviderNames;
            display_name: string;
        }[];
        emailPassword: boolean;
    }>;
    emailPasswordSignUp(data: {
        email: string;
        password: string;
    } | FormData): Promise<{
        tokenData?: TokenData | null;
    }>;
    emailPasswordResendVerificationEmail(data: {
        verification_token: string;
    } | {
        email: string;
    } | FormData): Promise<void>;
    emailPasswordSignIn(data: {
        email: string;
        password: string;
    } | FormData): Promise<{
        tokenData?: TokenData;
        error?: Error;
    }>;
    emailPasswordSendPasswordResetEmail(data: {
        email: string;
    } | FormData): Promise<void>;
    emailPasswordResetPassword(data: {
        reset_token: string;
        password: string;
    } | FormData): Promise<{
        tokenData: TokenData;
    }>;
    magicLinkSignUp(data: {
        email: string;
    } | FormData): Promise<void>;
    magicLinkSend(data: {
        email: string;
    } | FormData): Promise<void>;
    webAuthnSignIn(data: {
        email: string;
        assertion: AuthenticationResponseJSON;
    }): Promise<{
        tokenData: TokenData;
    }>;
    webAuthnSignUp(data: {
        email: string;
        credentials: RegistrationResponseJSON;
        verify_url: string;
        user_handle: string;
    }): Promise<{
        tokenData: TokenData | null;
    }>;
    signout(): Promise<void>;
}
export declare class AuthSession {
    private readonly authToken;
    readonly client: Client;
    isSignedIn(): Promise<boolean | null>;
}
